pub enum Runtime {
Tokio1,
AsyncStd1,
}Available on crate feature
sqlite only.Expand description
Enumeration for picking a runtime implementation.
Variants
Tokio1
Available on crate feature
tokio_1 only.tokio 1.0 runtime.
AsyncStd1
Available on crate feature
async-std_1 only.async-std 1.0 runtime.
Implementations
Sourceimpl Runtime
impl Runtime
Sourcepub async fn timeout<F>(
&self,
duration: Duration,
future: F,
) -> Option<<F as Future>::Output>where
F: Future,
Available on crate feature mysql only.
pub async fn timeout<F>(
&self,
duration: Duration,
future: F,
) -> Option<<F as Future>::Output>where
F: Future,
mysql only.Requires a Future to complete before the specified duration has
elapsed.
If the future completes before the duration has elapsed, then the
completed value is returned. Otherwise, an error is returned and
the future is canceled.
Sourcepub async fn spawn_blocking<F, R>(&self, f: F) -> Result<R, SpawnBlockingError>
Available on crate feature mysql only.
pub async fn spawn_blocking<F, R>(&self, f: F) -> Result<R, SpawnBlockingError>
mysql only.Runs the given closure on a thread where blocking is acceptable.
Errors
See SpawnBlockingError for details.
Sourcepub fn spawn_blocking_background<F>(
&self,
f: F,
) -> Result<(), SpawnBlockingError>
Available on crate feature mysql only.
pub fn spawn_blocking_background<F>( &self, f: F, ) -> Result<(), SpawnBlockingError>
mysql only.Runs the given closure on a thread where blocking is acceptable.
It works similar to Runtime::spawn_blocking() but doesn’t return a
Future and is meant to be used for background tasks.
Errors
See SpawnBlockingError for details.