pub struct Manager<C> { /* private fields */ }Expand description
Connection Manager for use with diesel.
See the deadpool documentation for usage examples.
Implementations
Sourceimpl<C> Manager<C>where
C: Connection,
impl<C> Manager<C>where
C: Connection,
Sourcepub fn new<S: Into<String>>(database_url: S, runtime: Runtime) -> Self
pub fn new<S: Into<String>>(database_url: S, runtime: Runtime) -> Self
Creates a new Manager which establishes Connections to the given
database_url.
Sourcepub fn from_config(
database_url: impl Into<String>,
runtime: Runtime,
manager_config: ManagerConfig<C>,
) -> Self
pub fn from_config( database_url: impl Into<String>, runtime: Runtime, manager_config: ManagerConfig<C>, ) -> Self
Creates a new Manager which establishes Connections to the given
database_url with a specific ManagerConfig.